Estimation of p values
calc_p.RdThis function is used to calculate p-value from a list of matrices
Usage
calc_p(X = NULL, type = c("g", "l"))Arguments
- X
list of matrices, where the first is the one obtained with real data and the others are obtained through permutations. The matrices should be 1 column matrices with the same order.
- type
g for >=, l <= than the real values
Details
the functions calculate p-value for a permutation-based approach. It takes as an input a list of matrices, where the first is the one with the real data and the other are the data obtained through permutations. Then, the function searches for how many values in the permutations are equal or higher to the real. These values are then divided by the number matrices (1 + number of permutations)