Skip to contents

Define significance for enriched genes

Usage

cmp_top_net_scores(NRRes = NULL, netEnrRes = NULL, top = 5, out_dir = NULL)

Arguments

NRRes

dataframe resulting from network resampling from package dmfind dmfind::NR()

netEnrRes

dataframe resulting from assess_enrichment()

top

number of top ranks that will be plotted in red

out_dir

output directory