Skip to contents

Function for the assignment of edges weights in order to better visualize the communities

Usage

edge_weights(community, network, weightWithin=100, 
weightBetween=1)

Arguments

community

list with the mandatory field "membership"

network

pathway network

weightWithin

value to weight the attraction between two vertices of the same community

weightBetween

value to weight the attraction between two vertices of two disntict communities

Value

vector of edge weights

Examples

if (FALSE) edge_weights(community, network, weightWithin=100, 
weightBetween=1)