Skip to contents

Get a gene set score from Xs matrix

Usage

get_gs_score(Xs = NULL, gsl = NULL, FUN = NULL)

Arguments

Xs

Xs matrix

gsl

named list of gene sets, which must match the row names of X

FUN

function to use to calculate the gene set score from the element of Xs; mean() by default