Skip to contents

Permutation of input matrix X

Usage

perm_mat(X = NULL, perms = NULL, columns = FALSE)

Arguments

X

matrix; a score matrix X, in which each column (layer) is a score vector over all vertices of A.

perms

list of permutations of the rownames of X, obtained by means of permute_vertices().

columns

whether to apply the permutation to the columns.

Value

list with permutations of X (where the first element of the list contains real data)