Skip to contents

Provide a summary score for he networks composed of a ranked list of genes

Usage

score_networks_summary(
  net_scores = NULL,
  LCC = FALSE,
  minpeakdistance = 1,
  minpeakheight = 0,
  ...
)

Arguments

net_scores

the table provided by the function score_networks()

LCC

whether to consider the largest connected components (TRUE) instead of considering all connected components (FALSE, default)

minpeakdistance

the minimum distance (in indices) peaks have to have to be counted

minpeakheight

the minimum (absolute) height a peak has to have to be recognized as such

...

further argumnts for pracma::findpeaks()

Value

A data frame with:

  • the input scores normalized to their maximum; not_linkers is 1 minus linkers (divided to their maximum);

  • y: the summary score, which is the sum of the previous columns;

  • peak: the presence of a peak in y.