Network Diffusion
ND.RdNetwork Diffusion
Arguments
- X0
vector or matrix composed of column vectors with initial distribution of information
- W
symmetrically normalized adjacency matrix W = D^-1 A D^-1, see normalize_adj_mat function
- alpha
numeric, the smothing factor
- nMax
numeric, maximum number of iterations
- eps
numeric, the iteration will stop when the maximum difference between matrix Xs between two consecutive iteraction is smaller than
eps- finalSmooth
TRUE/FALSE, whether to do the final step of smoothing
- fullOutput,
TRUE/FALSE, whether to output all steps
- verbose,
TRUE/FALSE