assess enrichment of the top networks
assess_enrichment.Rdassess enrichment of the top networks
Usage
assess_enrichment(
G = NULL,
topList = NULL,
ranks = NULL,
X0Vector = NULL,
type = c("ora", "gsea"),
k = 99,
minComponentSize = 2,
minNetSize = 10,
minKNes = 10,
BPPARAMGsl = NULL,
BPPARAMK = NULL
)Arguments
- G
igraph object
- topList
ranked list of vertex names that will be used to define top networks
- ranks
ranks of topList that will be assessed
- X0Vector
named numeric vector that will be tested with GSEA or ORA. In case of GSEA it will be ranked by decreasing orderg, while in the case of ORA the names of the X0 values grater than 0 will be tested for enrichment, while all X0 names will be the universe.
- type
gsea or ora
- k
number of permutations
- minComponentSize
size of the smallest graph component
- minNetSize
minimum network size
- minKNes
minimum k for considering a NES "confident"
- BPPARAMGsl
BiocParallelParam instance to parallelize over gene sets. See
BiocParallel::bplapply()- BPPARAMK
BiocParallelParam instance to paralleliz over permutations.
BiocParallel::bplapply()