Function for the assignment of edges weights in order to better visualize the communities
edge_weights.RdFunction for the assignment of edges weights in order to better visualize the communities
edge_weights.RdFunction for the assignment of edges weights in order to better visualize the communities