Enrichment map
enrichment_map.RdThis functions calculates similarities between gene-sets and plot a resulting enrichment map
Usage
enrichment_map(
gs_scores = NULL,
gene_set_sim = NULL,
min_sim = 0.2,
clustering_f = cluster_fast_greedy,
min_comp_size = 1,
gs_size = NULL,
verbose = TRUE
)Arguments
- gs_scores
named vector of pathway scores
- gene_set_sim
gene set similarity calculated through
calc_gs_sim()- min_sim
threshold for the similarity score between two gene sets
- clustering_f
graph clustering function,
igraph::cluster_fast_greedy()by default- min_comp_size
minimum size of a community to be considered in the enrichment map then all gene-sets are displayed
- gs_size
named vector with size of the gene-sets in
gs_scores- verbose
verbosity
Details
enrichment_map() function calculates similarities between each gene-set pair by using method metric. Subsequently,
these similarities are filtered to maintain the ones >= min_sim. clustering_f function is then used to identify communities,
which may be filtered to plot only the ones composed by at least min_comp_size gene-sets.