get_gs_score.Rd
Get a gene set score from Xs matrix
get_gs_score(Xs = NULL, gsl = NULL, FUN = NULL)
Xs matrix
named list of gene sets, which must match the row names of X
function to use to calculate the gene set score from the element of Xs; mean() by default