Permutation of input matrix X0
Usage
perm_X0(X0 = NULL, perms = NULL)
Arguments
- X0
matrix; a score matrix X0, in which each column (layer) is a score vector over all vertices of A.
- perms
list of permutations of the rownames of X0, obtained by means of permute_vertices()
Value
list with permutations of X0 (where the first element of the list contains real data)