Plot heatmap of GSEA results for multiple runs
plot_gsea_heatmap.RdPlot heatmap of GSEA results for multiple runs
Usage
plot_gsea_heatmap(
gsea_res = NULL,
nes_sign = TRUE,
a = 0.25,
p.stat = "FDRq",
na_col = "khaki",
max_gs = 50,
min.p = NA,
...
)Arguments
- gsea_res
result of function gsea()
- nes_sign
whether to print nes sign
- a
alpha over FDR
- p.stat
column where p-values are taken from
- na_col
color for FDR > a
- max_gs
maximum number of gene sets that will be plotted
- min.p
p-values below this values will be set to NA
- ...
further arguments to
ComplexHeatmap::Heatmap()