Plot heatmap of ORA results for multiple runs
Usage
plot_ora_heatmap(
ora_res = NULL,
p.stat = "p_adj",
a = 0.25,
na_col = "khaki",
min.p = NA,
max_gs = 50,
...
)
Arguments
- ora_res
result of function gsea()
- p.stat
p-value that will be plotted
- a
alpha over FDR
- na_col
color for FDR > a
- min.p
p-values below this values will be set to NA
- max_gs
maximum number of gene sets that will be plotted
- ...
further arguments to ComplexHeatmap::Heatmap()