Score the networks composed of a ranked list of genes
score_networks.RdThe networks are scored by:
modularity;
network components;
omega z-score peaks;
presence of linkers.
Usage
score_networks(
g_CC_LCC = NULL,
X0 = NULL,
X0_column = 1,
NRsummary = NULL,
commMethods = "fastgreedy",
BPPARAM = NULL
)Arguments
- g_CC_LCC
list of CC and LCC as produced by means of calc_CC_LCC()
- X0
the X0 matrix
- X0_column
the column of X0 that will be considered
- NRsummary
NRsummary element of the output of function NR()
- commMethods
community method(s) that will be considered
- BPPARAM
optional BBPARAM
Value
A data frame with the following quantities for CC and LCC:
X0_: sum of the X0 values in the network divided by the sum of the n genes with the highest X0 values, where n network size (CC or LCC);linkers: fraction of linkers, that is, genes with X0(i) equal to 0;omega: NR omega value;z: omega z-score;p_val: omega p_val;n_V_: number of vertices;n_E_: number of links;a_: algorithm used to find the communities;Q_: modularity;n_comm_: number of communities.